#!/usr/bin/env python
#
# Copyright (C) 2012  W. Trevor King <wking@tremily.us>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Freely rotating chain (FRC) following Livadaru et al. [1].

[1]: http://pubs.acs.org/doi/abs/10.1021/ma020751g
"""

import numpy as _numpy
import matplotlib.pyplot as _pyplot
try:  # SciPy >= 0.10.0
    from scipy.constants import Boltzmann as _kB
except ImportError:  # SciPy < 0.10.0
    from scipy.constants import Bolzmann as _kB

from crunch import inverse_frc


def figure_14():
    figure = _pyplot.figure()
    axes = figure.add_subplot(1, 1, 1)
    axes.set_xscale('log')
    axes.set_yscale('log')
    axes.hold(True)
    Fs = 10**_numpy.linspace(-4, 2.2, 100)
    for gamma_degrees in [1, 5, 10, 20, 30, 50, 70]:
        gamma = gamma_degrees * _numpy.pi / 180
        xs = _numpy.array([inverse_frc(F, gamma) for F in Fs])
        axes.plot(Fs, 1/(1-xs))
    axes.axis([Fs.min(), Fs.max(), 0.9, 500])
    axes.set_title('FRC force extension')
    axes.set_xlabel(r'$\frac{fb}{k_B T}$')
    axes.set_ylabel(r'$\left(1-\frac{R_z}{L}\right)^{-1}$')
    figure.subplots_adjust(bottom=0.13)
    return figure


if __name__ == '__main__':
    figure = figure_14()
    figure.savefig('figure-14.png')
    #_pyplot.show()
